bayespy.inference.vmp.nodes.gaussian.GaussianGammaISOMoments
============================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. autoclass:: GaussianGammaISOMoments

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~GaussianGammaISOMoments.__init__
      ~GaussianGammaISOMoments.add_converter
      ~GaussianGammaISOMoments.compute_dims_from_values
      ~GaussianGammaISOMoments.compute_fixed_moments
      ~GaussianGammaISOMoments.get_converter
   
   

   
   
   